@@ -5,8 +5,8 @@ from __future__ import absolute_import
 # import apis into api package
 from pulpcore.client.pulp_container.api.content_blobs_api import ContentBlobsApi
 from pulpcore.client.pulp_container.api.content_manifests_api import ContentManifestsApi
+from pulpcore.client.pulp_container.api.content_signatures_api import ContentSignaturesApi
 from pulpcore.client.pulp_container.api.content_tags_api import ContentTagsApi
-from pulpcore.client.pulp_container.api.contentguards_content_redirect_api import ContentguardsContentRedirectApi
 from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi
 from pulpcore.client.pulp_container.api.pulp_container_namespaces_api import PulpContainerNamespacesApi
 from pulpcore.client.pulp_container.api.remotes_container_api import RemotesContainerApi
